==> openGion8.2.0.0_src.zip: uap/webapps/gf/src/org/opengion/hayabusa/db/AbstractRenderer.java <==
/*
 * Copyright (c) 2009 The openGion Project.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.opengion.hayabusa.db;

import org.opengion.fukurou.util.StringUtil ;		// 6.2.0.0 (2015/02/27)
import org.opengion.fukurou.system.HybsConst ;		// 6.1.0.0 (2014/12/26)

/**
 * DBCell の具象クラスで、カラムのデータを表示する場合に使用するクラスです。
 *
 *  カラムの表示に必要な属性は, DBColumn オブジェクト より取り出します。
 * このクラスは、DBColumn オブジェクト毎に１つ作成されます。
 *
 * @og.group データ表示
 *
 * @version  4.0
 * @author   Kazuhiko Hasegawa
 * @since    JDK5.0,
 */
public abstract class AbstractRenderer implements CellRenderer {
	/** システムの改行コードを設定します。*/
	protected static final String CR		 = HybsConst.CR;			// 6.1.0.0 (2014/12/26) refactoring
	/** StringBilderなどの初期値を設定します。	{@value} */
	protected static final int BUFFER_MIDDLE = HybsConst.BUFFER_MIDDLE;	// 6.1.0.0 (2014/12/26) refactoring

	/**
	 * デフォルトコンストラクター
	 *
	 * @og.rev 6.4.2.0 (2016/01/29) PMD refactoring. Each class should declare at least one constructor.
	 */
	protected AbstractRenderer() { super(); }		// これも、自動的に呼ばれるが、空のメソッドを作成すると警告されるので、明示的にしておきます。

	/**
	 * データの表示用文字列を返します。
	 *
	 * @og.rev 6.0.4.0 (2014/11/28) ロジックの共通化
	 *
	 * @param   value 入力値
	 *
	 * @return  データの表示用文字列
	 * @og.rtnNotNull
	 */
	public String getValue( final String value ) {
		return value==null ? "" : value ;					// 6.0.4.0 (2014/11/28) ロジックの共通化
	}

	/**
	 * name属性を変えた、データ表示/編集用のHTML文字列を作成します。
	 * テーブル上の name に 行番号を付加して、名前_行番号 で登録するキーを作成し,
	 * リクエスト情報を１つ毎のフィールドで処理できます。
	 *
	 * @param	row  	行番号
	 * @param   value 入力値
	 *
	 * @return  データ表示/編集用の文字列
	 * @og.rtnNotNull
	 * @see		#getValue( String )
	 */
	public String getValue( final int row,final String value ) {
		return getValue( value );
	}

	/**
	 * name属性を変えた、データ表示用のHTML文字列を作成します。
	 * レンデラーのため、row(行番号)は使いません。
	 * 第３引数に、パラメータを渡すことが出来ます。これは、viewMarker で
	 * [$XXXX param] 形式を渡すことで、行単位に表示形式を変更できます。
	 * AbstractRenderer では、#getValue( String ) を呼び出しています。
	 *
	 * @og.rev 6.8.3.1 (2017/12/01) パラメータを渡せるようにします。
	 *
	 * @param   row   行番号
	 * @param   value 値
	 * @param   param パラメータ
	 *
	 * @return  データ表示/編集用の文字列
	 */
	public String getValue( final int row,final String value,final String param ) {
		return getValue( value );
	}

	/**
	 * データ出力用の文字列を作成します。
	 * ファイル等に出力する形式を想定しますので、HTMLタグを含まない
	 * データを返します。
	 * 基本は、#getValue( String ) をそのまま返します。
	 *
	 * @og.rev 6.0.4.0 (2014/11/28) データ出力用のレンデラー
	 * @og.rev 6.2.0.0 (2015/02/27) StringUtil#spanCut(String) を入れます。
	 * @og.rev 6.2.4.2 (2015/05/29) StringUtil#spanCut(String) → StringUtil#tagCut(String) に変更します。
	 *
	 * @param   value 入力値
	 *
	 * @return  データ出力用の文字列
	 * @og.rtnNotNull
	 * @see		#getValue( String )
	 */
	public String getWriteValue( final String value ) {
		return StringUtil.tagCut( getValue( value ) );					// 6.2.4.2 (2015/05/29)
	}
}

==> openGion8.3.0.4_src.zip: uap/webapps/gf/src/org/opengion/hayabusa/db/AbstractRenderer.java <==
/*
 * Copyright (c) 2009 The openGion Project.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.opengion.hayabusa.db;

import org.opengion.fukurou.util.StringUtil ;		// 6.2.0.0 (2015/02/27)
import org.opengion.fukurou.system.HybsConst ;		// 6.1.0.0 (2014/12/26)

/**
 * DBCell の具象クラスで、カラムのデータを表示する場合に使用するクラスです。
 *
 *  カラムの表示に必要な属性は, DBColumn オブジェクト より取り出します。
 * このクラスは、DBColumn オブジェクト毎に１つ作成されます。
 *
 * @og.group データ表示
 *
 * @version  4.0
 * @author   Kazuhiko Hasegawa
 * @since    JDK5.0,
 */
public abstract class AbstractRenderer implements CellRenderer {
	/** システムの改行コードを設定します。*/
	protected static final String CR		 = HybsConst.CR;			// 6.1.0.0 (2014/12/26) refactoring
	/** StringBilderなどの初期値を設定します。	{@value} */
	protected static final int BUFFER_MIDDLE = HybsConst.BUFFER_MIDDLE;	// 6.1.0.0 (2014/12/26) refactoring

	/**
	 * デフォルトコンストラクター
	 *
	 * @og.rev 6.4.2.0 (2016/01/29) PMD refactoring. Each class should declare at least one constructor.
	 */
	protected AbstractRenderer() { super(); }		// これも、自動的に呼ばれるが、空のメソッドを作成すると警告されるので、明示的にしておきます。

	/**
	 * データの表示用文字列を返します。
	 *
	 * @og.rev 6.0.4.0 (2014/11/28) ロジックの共通化
	 *
	 * @param   value 入力値
	 *
	 * @return  データの表示用文字列
	 * @og.rtnNotNull
	 */
	@Override	// CellRenderer
	public String getValue( final String value ) {
		return value==null ? "" : value ;					// 6.0.4.0 (2014/11/28) ロジックの共通化
	}

	/**
	 * name属性を変えた、データ表示/編集用のHTML文字列を作成します。
	 * テーブル上の name に 行番号を付加して、名前_行番号 で登録するキーを作成し,
	 * リクエスト情報を１つ毎のフィールドで処理できます。
	 *
	 * @param	row  	行番号
	 * @param   value 入力値
	 *
	 * @return  データ表示/編集用の文字列
	 * @og.rtnNotNull
	 * @see		#getValue( String )
	 */
	@Override	// CellRenderer
	public String getValue( final int row,final String value ) {
		return getValue( value );
	}

	/**
	 * name属性を変えた、データ表示用のHTML文字列を作成します。
	 * レンデラーのため、row(行番号)は使いません。
	 * 第３引数に、パラメータを渡すことが出来ます。これは、viewMarker で
	 * [$XXXX param] 形式を渡すことで、行単位に表示形式を変更できます。
	 * AbstractRenderer では、#getValue( String ) を呼び出しています。
	 *
	 * @og.rev 6.8.3.1 (2017/12/01) パラメータを渡せるようにします。
	 *
	 * @param   row   行番号
	 * @param   value 値
	 * @param   param パラメータ
	 *
	 * @return  データ表示/編集用の文字列
	 */
	@Override	// CellRenderer
	public String getValue( final int row,final String value,final String param ) {
		return getValue( value );
	}

	/**
	 * データ出力用の文字列を作成します。
	 * ファイル等に出力する形式を想定しますので、HTMLタグを含まない
	 * データを返します。
	 * 基本は、#getValue( String ) をそのまま返します。
	 *
	 * @og.rev 6.0.4.0 (2014/11/28) データ出力用のレンデラー
	 * @og.rev 6.2.0.0 (2015/02/27) StringUtil#spanCut(String) を入れます。
	 * @og.rev 6.2.4.2 (2015/05/29) StringUtil#spanCut(String) → StringUtil#tagCut(String) に変更します。
	 *
	 * @param   value 入力値
	 *
	 * @return  データ出力用の文字列
	 * @og.rtnNotNull
	 * @see		#getValue( String )
	 */
	@Override	// CellRenderer
	public String getWriteValue( final String value ) {
		return StringUtil.tagCut( getValue( value ) );					// 6.2.4.2 (2015/05/29)
	}
}
